v1.3.0
======

Require Python 3.6 or later.

1.2
===

Refresh project skeleton and enable continuous integration and
automated deployments.

1.1
===

Moved hosting to Github.

1.0.2
=====

Restore Python 3 compatibility.

1.0.1
=====

Restore compatibility with Setuptools 19.3 by no longer relying on
setuptools.compat.

1.0
===

Initial release, based on implementation extracted from Setuptools 8.3.
